@@ -5,7 +5,8 @@ from .hmanifold import HomogenousManifold
 
 
 class HeavyTop(HomogenousManifold):
-    def __init__(self, y):
+    """Manifold on which the Heavy Top equations evolve. Corresponding Lie group SE(3)."""
+    def __init__(self, y=np.array([1, 0, 0, 1, 0, 0])):
         if not isinstance(y, np.ndarray):
             try:
                 y = np.array(y)
@@ -15,4 +16,5 @@ class HeavyTop(HomogenousManifold):
         self.y = y
         self.lie_group = SELieGroup()
         self.lie_algebra = seLieAlgebra(self.lie_group)
+
         super().__init__()
